@@ -16,7 +16,6 @@ from typing import Optional, Set
 
 from datasource.identity import Identity
 from datasource.sqlite.sqlite_repository import SQLiteRepository
-from hspylib.core.tools.text_tools import quote
 
 from vault.entity.vault_entry import VaultEntry
 
@@ -28,12 +27,17 @@ class VaultRepository(SQLiteRepository[VaultEntry]):
 
     def find_by_key(self, key: str, fields: Set[str] = None) -> Optional[VaultEntry]:
         fields = "*" if not fields else ", ".join(fields)
-        clause = f"key = {quote(key)}"
-        sql = f"SELECT {fields} FROM {self.table_name()} WHERE {clause} ORDER BY key"
-        result = next((e for e in self.execute(sql)[1]), None)
+        sql = f"SELECT {fields} FROM {self.table_name()} WHERE key = ? ORDER BY key"
+        result = next((e for e in self.execute(sql, key=key)[1]), None)
 
         return self.to_entity_type(result) if result else None
 
+    def exists(self, key: str) -> bool:
+        sql = f"SELECT rowid FROM {self.table_name()} WHERE key = ?"
+        result = next((e for e in self.execute(sql, key=key)[1]), None)
+
+        return bool(result)
+
     def table_name(self) -> str:
         return "VAULT_ENTRIES"
 
@@ -42,10 +46,5 @@ class VaultRepository(SQLiteRepository[VaultEntry]):
             return VaultEntry(Identity(VaultEntry.VaultId(entity_dict["uuid"])), **entity_dict)
         return VaultEntry(
             Identity(VaultEntry.VaultId(entity_dict[0])),
-            uuid=entity_dict[0],
-            key=entity_dict[1],
-            name=entity_dict[2],
-            password=entity_dict[3],
-            hint=entity_dict[4],
-            modified=entity_dict[5],
+            entity_dict[1], entity_dict[2], entity_dict[3], entity_dict[4], entity_dict[5]
         )
